@@ -290,10 +290,8 @@ def setup(app: Sphinx) -> SphinxExtMetadata:
 	app.setup_extension("sphinx.ext.autosummary")
 	app.setup_extension("autodocsumm")
 
-	# app.add_directive('autosummary', PatchedAutosummary, override=True)
-
+	app.add_directive('autosummary', PatchedAutosummary, override=True)
 	autodocsumm.AutosummaryDocumenter.add_autosummary = add_autosummary
-
 	allow_subclass_add(app, PatchedAutoSummClassDocumenter)
 
 	app.add_config_value(
